<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compagnon?lang_cible=es
// ** ne pas modifier le fichier **

return [

	// C
	'compagnon_description' => 'El compañero ofrece ayuda a los usuarios durante su primera visita al espacio privado de SPIP.',
	'compagnon_nom' => 'Compañero',
	'compagnon_slogan' => 'Asistente para dar los primeros pasos con SPIP',
];
